@@ -28,7 +28,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.29';
+our $VERSION = '2.30';
 
 =head1 SYNOPSIS
 
@@ -135,6 +135,19 @@ has 'jobname' => (
     documentation => q{Specify a job name, each job will be appended with its batch order},
 );
 
+=head2 afterok
+=cut
+has afterok => (
+    is        => 'rw',
+    isa     => 'ArrayRef',
+    required => 0,
+    default => sub {
+        return [];
+    },
+);
+
+
+
 =head2 cpus_per_task
 
 slurm item --cpus_per_task defaults to 8, which is probably fine
@@ -683,6 +696,14 @@ Batch commands in groups of $self->cpus_per_task, or smaller as wait and nextnod
 sub parse_file_slurm{
     my $self = shift;
     my $fh = IO::File->new( $self->infile, q{<} ) or print "Error opening file  ".$self->infile."  ".$!; # even better!
+
+    if($self->afterok){
+        $self->wait(1);
+        $self->jobref->[0] = $self->afterok;
+        push(@{$self->jobref}, []);
+    }
+    $DB::single=2;
+
     while(<$fh>){
         my $line = $_;
         next unless $line;
